==> wxPython-src-2.9.1.1.tar.bz2: wxPython-src-2.9.1.1/docs/doxygen/mainpages/const_stockitems.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        const_stockitems.h
// Purpose:     stock item values enumerated
// Author:      wxWidgets team
// RCS-ID:      $Id: const_stockitems.h 64940 2010-07-13 13:29:13Z VZ $
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////


/**

@page page_stockitems Stock items

The following is the list of the window IDs for which stock buttons and menu items
are created.
See the wxButton constructor and the wxMenuItem constructor for classes which
automatically add stock bitmaps when using stock IDs.
Also note that you can retrieve stock bitmaps using wxArtProvider.

@beginDefList
@row3col{<b>Stock ID</b>, <b>GTK icon</b>, <b>Stock label</b>}
@stock{wxID_ABOUT,about,&About...}
@stock{wxID_ADD,add,Add}
@stock{wxID_APPLY,apply,&Apply}
@stock{wxID_BACKWARD,go-back-ltr,&Back}
@stock{wxID_BOLD,bold,&Bold}
@stock{wxID_BOTTOM,goto-bottom,&Bottom}
@stock{wxID_CANCEL,cancel,&Cancel}
@stock{wxID_CDROM,cdrom,&CD-Rom}
@stock{wxID_CLEAR,clear,&Clear}
@stock{wxID_CLOSE,close,&Close}
@stock{wxID_CONVERT,convert,&Convert}
@stock{wxID_COPY,copy,&Copy}
@stock{wxID_CUT,cut,Cu&t}
@stock{wxID_DELETE,delete,&Delete}
@stock{wxID_DOWN,go-down,&Down}
@stock{wxID_EDIT,edit,&Edit}
@stock{wxID_EXECUTE,execute,&Execute}
@stock{wxID_EXIT,quit,&Quit}
@stock{wxID_FILE,file,&File}
@stock{wxID_FIND,find,&Find}
@stock{wxID_FIRST,goto-first-ltr,&First}
@stock{wxID_FLOPPY,floppy,&Floppy}
@stock{wxID_FORWARD,go-forward-ltr,&Forward}
@stock{wxID_HARDDISK,harddisk,&Harddisk}
@stock{wxID_HELP,help,&Help}
@stock{wxID_HOME,home,&Home}
@stock{wxID_INDENT,indent-ltr,Indent}
@stock{wxID_INDEX,index,&Index}
@stock{wxID_INFO,info,&Info}
@stock{wxID_ITALIC,italic,&Italic}
@stock{wxID_JUMP_TO,jump-to-ltr,&Jump to}
@stock{wxID_JUSTIFY_CENTER,justify-center,Centered}
@stock{wxID_JUSTIFY_FILL,justify-fill,Justified}
@stock{wxID_JUSTIFY_LEFT,justify-left,Align Left}
@stock{wxID_JUSTIFY_RIGHT,justify-right,Align Right}
@stock{wxID_LAST,goto-last-ltr,&Last}
@stock{wxID_NETWORK,network,&Network}
@stock{wxID_NEW,new,&New}
@stock{wxID_NO,no,&No}
@stock{wxID_OK,ok,&OK}
@stock{wxID_OPEN,open,&Open...}
@stock{wxID_PASTE,paste,&Paste}
@stock{wxID_PREFERENCES,preferences,&Preferences}
@stock{wxID_PREVIEW,print-preview,Print previe&w}
@stock{wxID_PRINT,print,&Print...}
@stock{wxID_PROPERTIES,properties,&Properties}
@stock{wxID_REDO,redo-ltr,&Redo}
@stock{wxID_REFRESH,refresh,Refresh}
@stock{wxID_REMOVE,remove,Remove}
@stock{wxID_REPLACE,find-and-replace,Rep&lace}
@stock{wxID_REVERT_TO_SAVED,revert-to-saved-ltr,Revert to Saved}
@stock{wxID_SAVE,save,&Save}
@stock{wxID_SAVEAS,save-as,Save &As...}
@stock{wxID_SELECTALL,select-all,Select &All}
@stock{wxID_SELECT_COLOR,select-color,&Color}
@stock{wxID_SELECT_FONT,select-font,&Font}
@stock{wxID_SORT_ASCENDING,sort-ascending,&Ascending}
@stock{wxID_SORT_DESCENDING,sort-descending,&Descending}
@stock{wxID_SPELL_CHECK,spell-check,&Spell Check}
@stock{wxID_STOP,stop,&Stop}
@stock{wxID_STRIKETHROUGH,strikethrough,&Strikethrough}
@stock{wxID_TOP,goto-top,&Top}
@stock{wxID_UNDELETE,undelete-ltr,Undelete}
@stock{wxID_UNDERLINE,underline,&Underline}
@stock{wxID_UNDO,undo-ltr,&Undo}
@stock{wxID_UNINDENT,unindent-ltr,&Unindent}
@stock{wxID_UP,go-up,&Up}
@stock{wxID_YES,yes,&Yes}
@stock{wxID_ZOOM_100,zoom-100,&Actual Size}
@stock{wxID_ZOOM_FIT,zoom-fit,Zoom to &Fit}
@stock{wxID_ZOOM_IN,zoom-in,Zoom &In}
@stock{wxID_ZOOM_OUT,zoom-out,Zoom &Out}
@endDefList

Note that some of the IDs listed above also have a stock accelerator
and an associated help string.

*/

==> wxPython-src-2.9.5.0.tar.bz2: wxPython-src-2.9.5.0/docs/doxygen/mainpages/const_stockitems.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        const_stockitems.h
// Purpose:     stock item values enumerated
// Author:      wxWidgets team
// RCS-ID:      $Id$
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////


/**

@page page_stockitems Stock Items

The following is the list of the window IDs for which stock buttons and menu
items are created.

See the wxButton constructor and the wxMenuItem constructor for classes which
automatically add stock bitmaps when using stock IDs.

Also note that you can retrieve stock bitmaps using wxArtProvider.

@beginDefList
@row3col{<b>Stock ID</b>, <b>GTK icon</b>, <b>Stock label</b>}
@stock{wxID_ABOUT,about,&About}
@stock{wxID_ADD,add,Add}
@stock{wxID_APPLY,apply,&Apply}
@stock{wxID_BACKWARD,go-back-ltr,&Back}
@stock{wxID_BOLD,bold,&Bold}
@stock{wxID_BOTTOM,goto-bottom,&Bottom}
@stock{wxID_CANCEL,cancel,&Cancel}
@stock{wxID_CDROM,cdrom,&CD-Rom}
@stock{wxID_CLEAR,clear,&Clear}
@stock{wxID_CLOSE,close,&Close}
@stock{wxID_CONVERT,convert,&Convert}
@stock{wxID_COPY,copy,&Copy}
@stock{wxID_CUT,cut,Cu&t}
@stock{wxID_DELETE,delete,&Delete}
@stock{wxID_DOWN,go-down,&Down}
@stock{wxID_EDIT,edit,&Edit}
@stock{wxID_EXECUTE,execute,&Execute}
@stock{wxID_EXIT,quit,&Quit}
@stock{wxID_FILE,file,&File}
@stock{wxID_FIND,find,&Find}
@stock{wxID_FIRST,goto-first-ltr,&First}
@stock{wxID_FLOPPY,floppy,&Floppy}
@stock{wxID_FORWARD,go-forward-ltr,&Forward}
@stock{wxID_HARDDISK,harddisk,&Harddisk}
@stock{wxID_HELP,help,&Help}
@stock{wxID_HOME,home,&Home}
@stock{wxID_INDENT,indent-ltr,Indent}
@stock{wxID_INDEX,index,&Index}
@stock{wxID_INFO,info,&Info}
@stock{wxID_ITALIC,italic,&Italic}
@stock{wxID_JUMP_TO,jump-to-ltr,&Jump to}
@stock{wxID_JUSTIFY_CENTER,justify-center,Centered}
@stock{wxID_JUSTIFY_FILL,justify-fill,Justified}
@stock{wxID_JUSTIFY_LEFT,justify-left,Align Left}
@stock{wxID_JUSTIFY_RIGHT,justify-right,Align Right}
@stock{wxID_LAST,goto-last-ltr,&Last}
@stock{wxID_NETWORK,network,&Network}
@stock{wxID_NEW,new,&New}
@stock{wxID_NO,no,&No}
@stock{wxID_OK,ok,&OK}
@stock{wxID_OPEN,open,&Open...}
@stock{wxID_PASTE,paste,&Paste}
@stock{wxID_PREFERENCES,preferences,&Preferences}
@stock{wxID_PREVIEW,print-preview,Print previe&w}
@stock{wxID_PRINT,print,&Print...}
@stock{wxID_PROPERTIES,properties,&Properties}
@stock{wxID_REDO,redo-ltr,&Redo}
@stock{wxID_REFRESH,refresh,Refresh}
@stock{wxID_REMOVE,remove,Remove}
@stock{wxID_REPLACE,find-and-replace,Rep&lace}
@stock{wxID_REVERT_TO_SAVED,revert-to-saved-ltr,Revert to Saved}
@stock{wxID_SAVE,save,&Save}
@stock{wxID_SAVEAS,save-as,Save &As...}
@stock{wxID_SELECTALL,select-all,Select &All}
@stock{wxID_SELECT_COLOR,select-color,&Color}
@stock{wxID_SELECT_FONT,select-font,&Font}
@stock{wxID_SORT_ASCENDING,sort-ascending,&Ascending}
@stock{wxID_SORT_DESCENDING,sort-descending,&Descending}
@stock{wxID_SPELL_CHECK,spell-check,&Spell Check}
@stock{wxID_STOP,stop,&Stop}
@stock{wxID_STRIKETHROUGH,strikethrough,&Strikethrough}
@stock{wxID_TOP,goto-top,&Top}
@stock{wxID_UNDELETE,undelete-ltr,Undelete}
@stock{wxID_UNDERLINE,underline,&Underline}
@stock{wxID_UNDO,undo-ltr,&Undo}
@stock{wxID_UNINDENT,unindent-ltr,&Unindent}
@stock{wxID_UP,go-up,&Up}
@stock{wxID_YES,yes,&Yes}
@stock{wxID_ZOOM_100,zoom-100,&Actual Size}
@stock{wxID_ZOOM_FIT,zoom-fit,Zoom to &Fit}
@stock{wxID_ZOOM_IN,zoom-in,Zoom &In}
@stock{wxID_ZOOM_OUT,zoom-out,Zoom &Out}
@endDefList

Note that some of the IDs listed above also have a stock accelerator and an
associated help string.

*/
